#ifndef __MDFN_TESTS_H
#define __MDFN_TESTS_H

namespace Mednafen
{

// Cheap is relative. ;)
// See also testsexp.h
void MDFN_RunCheapTests(void);

}

#endif

